/*
 * Copyright (c) Eugene Matyushkin 2007
 */
package ru.skipy.layout.circle;

import java.awt.*;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import static ru.skipy.layout.circle.CircleLayout.Direction;
import static ru.skipy.layout.circle.CircleLayout.Fill;

/**
 * CircleLayoutTest
 *
 * @author Eugene Matyushkin
 * @version $Id: CircleLayoutParamsTest.java 282 2007-10-22 07:49:54Z ematyushkin $
 */
public class CircleLayoutParamsTest extends JFrame {

    private CircleLayout layout;

    private JPanel panel;


    public CircleLayoutParamsTest() {
        super("Circle Layout params test");
        layout = new CircleLayout();
        panel = createPanel();
        JPanel cp = new JPanel(new GridBagLayout());
        cp.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
        cp.add(new JScrollPane(panel), new GridBagConstraints(0, 0, 2, 1, 1, 1, GridBagConstraints.CENTER,
            GridBagConstraints.BOTH, new Insets(0, 0, 5, 0), 0, 0));
        cp.add(new JLabel("Fill"), new GridBagConstraints(0, 1, 1, 1, 0, 0, GridBagConstraints.CENTER,
            GridBagConstraints.BOTH, new Insets(0, 0, 5, 5), 0, 0));
        final JComboBox cbxFill = new JComboBox(new Object[]{Fill.NONE, Fill.HORIZONTAL, Fill.VERTICAL, Fill.BOTH});
        cbxFill.setSelectedIndex(0);
        cp.add(cbxFill, new GridBagConstraints(1, 1, 1, 1, 1, 0, GridBagConstraints.CENTER, GridBagConstraints.BOTH,
            new Insets(0, 0, 5, 0), 0, 0));
        cp.add(new JLabel("Direction"), new GridBagConstraints(0, 2, 1, 1, 0, 0, GridBagConstraints.CENTER,
            GridBagConstraints.BOTH, new Insets(0, 0, 5, 5), 0, 0));
        final JComboBox cbxDirection = new JComboBox(new Object[]{Direction.CLOCKWISE, Direction.COUNTERCLOCWISE});
        cbxDirection.setSelectedIndex(0);
        cp.add(cbxDirection, new GridBagConstraints(1, 2, 1, 1, 1, 0, GridBagConstraints.CENTER,
            GridBagConstraints.BOTH, new Insets(0, 0, 5, 0), 0, 0));
        cp.add(new JLabel("Start angle"), new GridBagConstraints(0, 3, 1, 1, 0, 0, GridBagConstraints.CENTER,
            GridBagConstraints.BOTH, new Insets(0, 0, 5, 5), 0, 0));
        final JSlider sldAngle = new JSlider(JSlider.HORIZONTAL, 0, 360, 0);
        sldAngle.setPaintLabels(true);
        sldAngle.setPaintTicks(true);
        sldAngle.setPaintTrack(true);
        sldAngle.setMajorTickSpacing(30);
        sldAngle.setMinorTickSpacing(5);

        cp.add(sldAngle, new GridBagConstraints(1, 3, 1, 1, 1, 0, GridBagConstraints.CENTER, GridBagConstraints.BOTH,
            new Insets(0, 0, 5, 0), 0, 0));
        cbxFill.addItemListener(new ItemListener() {
            public void itemStateChanged(ItemEvent e) {
                if (e.getStateChange() == ItemEvent.DESELECTED) {
                    return;
                }
                layout.setFill((Fill)(cbxFill.getSelectedItem()));
                panel.doLayout();
            }
        });
        cbxDirection.addItemListener(new ItemListener() {
            public void itemStateChanged(ItemEvent e) {
                if (e.getStateChange() == ItemEvent.DESELECTED) {
                    return;
                }
                layout.setDirection((Direction)(cbxDirection.getSelectedItem()));
                panel.doLayout();
            }
        });
        sldAngle.addChangeListener(new ChangeListener() {
            public void stateChanged(ChangeEvent e) {
                layout.setStartAngle(2 * Math.PI * sldAngle.getValue() / 360);
                panel.doLayout();
            }
        });
        setContentPane(cp);
        setSize(400, 400);
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        setLocationRelativeTo(null);
    }


    public static void main(String[] args) {
        JFrame.setDefaultLookAndFeelDecorated(true);
        new CircleLayoutParamsTest().setVisible(true);
    }


    private JPanel createPanel() {
        JPanel panel = new JPanel();
        panel.setLayout(layout);
        for (int i = 0; i < 16; i++) {
            panel.add(createComponent(String.valueOf(i + 1)));
        }
        panel.setBorder(BorderFactory.createRaisedBevelBorder());
        return panel;
    }


/*    private JComponent createButton(String caption) {
        JButton btn = new JButton(caption);
        btn.setPreferredSize(new Dimension(50, 25));
        return btn;
    }
 */

    private JComponent createComponent(String caption) {
        JLabel lbl = new JLabel(caption);
        lbl.setPreferredSize(new Dimension(25, 25));
        lbl.setHorizontalAlignment(JLabel.CENTER);
        lbl.setBorder(BorderFactory.createLineBorder(Color.blue, 2));
        lbl.setBackground(Color.white);
        lbl.setOpaque(true);
        return lbl;
    }

}
